#!/usr/bin/perl
#

use Modern::Perl;
use utf8;

use Test::More tests => 10;

BEGIN {
    use_ok('Koha::Database');
}

my $database;
ok( $database = Koha::Database->new(), 'Created Koha::Database Object' );

my $schema;
ok( $schema = $database->schema(), 'Get a schema' );
my $dbh;
ok( $dbh = $schema->storage->dbh(), 'Get an old fashioned DBI dbh handle' );
ok( $schema->storage->connected(), 'Check our db connection is active' );
ok( $schema = $database->schema(), 'Try and get the same schema' );

my $new_schema;
ok( $new_schema = $database->new_schema(), 'Try to get a new schema' );
ok( $database->set_schema($new_schema), 'Switch to new schema' );
ok( $database->restore_schema(),        'Switch back' );

# run in a transaction
$schema->storage->txn_begin();

# clear the way
$schema->resultset('Category')->search({ categorycode => 'GIFT-RUS' })->delete;
my $gift = 'подарок';
$schema->resultset('Category')->create({
    categorycode => 'GIFT-RUS',
    description  => $gift,
});
my $desc = $schema->resultset('Category')->search({
    categorycode => 'GIFT-RUS',
})->single->get_column('description');
is($desc, $gift, 'stored and retrieved UTF8 string');
$schema->storage->txn_rollback();
